package log

import (
	"io"
	"io/ioutil"
	"log"
	"os"
)

var (
	Trace          *log.Logger
	Info           *log.Logger
	Warning        *log.Logger
	Error          *log.Logger
	TracingEnabled bool
)

func Init(
	traceHandle io.Writer,
	infoHandle io.Writer,
	warningHandle io.Writer,
	errorHandle io.Writer) {

	Trace = log.New(traceHandle,
		"Trace: ",
		log.Ldate|log.Ltime|log.Lshortfile)

	Info = log.New(infoHandle,
		"INFO: ",
		log.Ldate|log.Ltime|log.Lshortfile)

	Warning = log.New(warningHandle,
		"WARNING: ",
		log.Ldate|log.Ltime|log.Lshortfile)

	Error = log.New(errorHandle,
		"ERROR: ",
		log.Ldate|log.Ltime|log.Lshortfile)
}

func InitLog() {
	var trace io.Writer
	if os.Getenv("RMAPI_TRACE") == "1" {
		trace = os.Stdout
		TracingEnabled = true
	} else {
		trace = ioutil.Discard
	}

	Init(trace, os.Stdout, os.Stdout, os.Stderr)
}
